Nebari CLI — Nebari CLI documentation documentation

# Nebari CLI

## nebari

Nebari CLI 🪴

    nebari [OPTIONS] COMMAND [ARGS]...

Options

-V, --version

  Nebari version number

--import-plugin <plugins>

  Import nebari plugin

  Default:

--exclude-stage <excluded_stages>

  Exclude nebari stage(s) by name or regex

  Default:

--exclude-default-stages

  Exclude default nebari included stages

  Default:

    `False`

### deploy

Deploy the Nebari cluster from your [purple]nebari-config.yaml[/purple] file.

    nebari deploy [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration yaml file path

-o, --output <output_directory>

  output directory

  Default:

    `./`

--dns-provider <dns_provider>

  dns provider to use for registering domain name mapping ⚠️ moved to dns.provider in nebari-config.yaml

  Default:

    `False`

--dns-auto-provision

  Attempt to automatically provision DNS, currently only available for cloudflare ⚠️ moved to dns.auto_provision in nebari-config.yaml

  Default:

    `False`

--disable-prompt

  Disable human intervention

  Default:

    `False`

--disable-render

  Disable auto-rendering in deploy stage

  Default:

    `False`

--disable-checks

  Disable the checks performed after each stage

  Default:

    `False`

--skip-remote-state-provision

  Skip terraform state deployment which is often required in CI once the terraform remote state bootstrapping phase is complete

  Default:

    `False`

### destroy

Destroy the Nebari cluster from your [purple]nebari-config.yaml[/purple] file.

    nebari destroy [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration file path

-o, --output <output_directory>

  output directory

  Default:

    `./`

--disable-render

  Disable auto-rendering before destroy

  Default:

    `False`

--disable-prompt

  Destroy entire Nebari cluster without confirmation request. Suggested for CI use.

  Default:

    `False`

### dev

Development tools and advanced features.

    nebari dev [OPTIONS] COMMAND [ARGS]...

#### keycloak-api

Interact with the Keycloak REST API directly.

This is an advanced tool which can have potentially destructive consequences. Please use this at your own risk.

    nebari dev keycloak-api [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration file path

-r, --request <request>

  Required Send a REST API request, valid requests follow patterns found here: [green]keycloak.org/docs-api/15.0/rest-api[/green]

### info

    nebari info [OPTIONS]

### init

Create and initialize your [purple]nebari-config.yaml[/purple] file.

This command will create and initialize your [purple]nebari-config.yaml[/purple] :sparkles:

This file contains all your Nebari cluster configuration details and, is used as input to later commands such as [green]nebari render[/green], [green]nebari deploy[/green], etc.

If you’re new to Nebari, we recommend you use the Guided Init wizard. To get started simply run:

> [green]nebari init –guided-init[/green]

    nebari init [OPTIONS] [CLOUD_PROVIDER]:[local|existing|do|aws|gcp|azure]

Options

--guided-init, --no-guided-init

  [bold green]START HERE[/bold green] - this will guide you step-by-step to generate your [purple]nebari-config.yaml[/purple]. It is an [i]alternative[/i] to passing the options listed below.

  Default:

    `False`

-p, --project-name, --project <project_name>

  Required

-d, --domain-name, --domain <domain_name>

--namespace <namespace>
  Default:

    `dev`

--auth-provider <auth_provider>

  options: [‘password’, ‘GitHub’, ‘Auth0’, ‘custom’]

  Default:

    `AuthenticationEnum.password`

  Options:

    password | GitHub | Auth0 | custom

--auth-auto-provision, --no-auth-auto-provision
  Default:

    `False`

--repository <repository>

  options: [‘github.com’, ‘gitlab.com’]

  Options:

    github.com | gitlab.com

--repository-auto-provision, --no-repository-auto-provision
  Default:

    `False`

--ci-provider <ci_provider>

  options: [‘github-actions’, ‘gitlab-ci’, ‘none’]

  Default:

    `CiEnum.none`

  Options:

    github-actions | gitlab-ci | none

--terraform-state <terraform_state>

  options: [‘remote’, ‘local’, ‘existing’]

  Default:

    `TerraformStateEnum.remote`

  Options:

    remote | local | existing

--kubernetes-version <kubernetes_version>
  Default:

    `latest`

--ssl-cert-email <ssl_cert_email>

--disable-prompt, --no-disable-prompt
  Default:

    `False`

-o, --output <output>

  Output file path for the rendered config file.

  Default:

    `nebari-config.yaml`

Arguments

CLOUD_PROVIDER

  Optional argument

### keycloak

Interact with the Nebari Keycloak identity and access management tool.

    nebari keycloak [OPTIONS] COMMAND [ARGS]...

#### adduser

Add a user to Keycloak. User will be automatically added to the [italic]analyst[/italic] group.

    nebari keycloak adduser [OPTIONS]

Options

--user <add_users>

  Required Provide both: <username> <password>

-c, --config <config_filename>

  Required nebari configuration file path

#### export-users

Export the users in Keycloak.

    nebari keycloak export-users [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration file path

--realm <realm>

  realm from which users are to be exported

  Default:

    `nebari`

#### listusers

List the users in Keycloak.

    nebari keycloak listusers [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration file path

### render

Dynamically render the Terraform scripts and other files from your [purple]nebari-config.yaml[/purple] file.

    nebari render [OPTIONS]

Options

-o, --output <output_directory>

  output directory

  Default:

    `./`

-c, --config <config_filename>

  Required nebari configuration yaml file path

--dry-run

  simulate rendering files without actually writing or updating any files

  Default:

    `False`

### support

Support tool to write all Kubernetes logs locally and compress them into a zip file.

The Nebari team recommends k9s to manage and inspect the state of the cluster. However, this command occasionally helpful for debugging purposes should the logs need to be shared.

    nebari support [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration file path

-o, --output <output>

  output filename

  Default:

    `./nebari-support-logs.zip`

### upgrade

Upgrade your [purple]nebari-config.yaml[/purple].

Upgrade your [purple]nebari-config.yaml[/purple] after an nebari upgrade. If necessary, prompts users to perform manual upgrade steps required for the deploy process.

See the project [green]RELEASE.md[/green] for details.

    nebari upgrade [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration file path

--attempt-fixes

  Attempt to fix the config for any incompatibilities between your old and new Nebari versions.

  Default:

    `False`

### validate

Validate the values in the [purple]nebari-config.yaml[/purple] file are acceptable.

    nebari validate [OPTIONS]

Options

-c, --config <config_filename>

  Required nebari configuration yaml file path, please pass in as -c/–config flag

--enable-commenting

  Toggle PR commenting on GitHub Actions

  Default:

    `False`